# chess-ant

Simulator to solve chess problems with MCTS Solver and Genetic Programming.

`chess_ant.py` is based on the code of
[deap/examples/gp/ant.py](https://github.com/DEAP/deap/blob/master/examples/gp/ant.py).


## Documentation

English:

- [Online](https://chess-ant.readthedocs.io/en/latest/)
- [latest PDF](https://chess-ant.readthedocs.io/_/downloads/en/latest/pdf/)
- [latest HTMLZip](https://chess-ant.readthedocs.io/_/downloads/en/latest/htmlzip/)
- [latest Epub](https://chess-ant.readthedocs.io/_/downloads/en/latest/epub/)

Japanese:

- [Online](https://chess-ant.readthedocs.io/ja/latest/)
- [latest PDF](https://chess-ant.readthedocs.io/_/downloads/ja/latest/pdf/)
- [latest HTMLZip](https://chess-ant.readthedocs.io/_/downloads/ja/latest/htmlzip/)
- [latest Epub](https://chess-ant.readthedocs.io/_/downloads/ja/latest/epub/)
